pub struct FeedMessage {
pub header: FeedHeader,
pub entity: Vec<FeedEntity>,
}Expand description
The contents of a feed message. A feed is a continuous stream of feed messages. Each message in the stream is obtained as a response to an appropriate HTTP GET request. A realtime feed is always defined with relation to an existing GTFS feed. All the entity ids are resolved with respect to the GTFS feed. Note that “required” and “optional” as stated in this file refer to Protocol Buffer cardinality, not semantic cardinality. See reference.md at https://github.com/google/transit/tree/master/gtfs-realtime for field semantic cardinality.
Fields
header: FeedHeaderMetadata about this feed and feed message.
entity: Vec<FeedEntity>Contents of the feed.