pub struct Translation {
pub text: String,
pub language: Option<String>,
}Fields
text: StringA UTF-8 string containing the message.
language: Option<String>BCP-47 language code. Can be omitted if the language is unknown or if no i18n is done at all for the feed. At most one translation is allowed to have an unspecified language tag.
Implementations